<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

class Review_admin extends \Ciext\Controller\AbstractAdminController
{

    public function index()
    {
        $this->load->model('review/crud_review');

        return ['content' => $this->crud_review->render(), 'title' => $this->lang->line('Reviews')];
    }

}
