<?php
$this->ciext->load_jquery();
$this->js_css->add_js('//cdn.jsdelivr.net/npm/slick-carousel@1.8.1/slick/slick.min.js');
$this->js_css->add_css('//cdn.jsdelivr.net/npm/slick-carousel@1.8.1/slick/slick.css');
$this->js_css->parse_js('review/init.js');
?>
<div class="wrap reviews_slider_wrap">
    <img alt="" src="/assets/img/reviews_ico.png" />
    <div class="reviews_slider">
        {items}
        <div>
            <p>{text}</p>
            <strong>{author}</strong>
        </div>
        {/items}
    </div>
</div>