$(function () {
    $('.reviews_slider').slick({
        dots: false,
        arrows: false,
        infinite: true,
        autoplay: true,
        autoplaySpeed: 10000,
        fade: true,
        cssEase: 'linear'
    });
});