CREATE TABLE IF NOT EXISTS `review` ( 
`id_review` int(11) NOT NULL AUTO_INCREMENT,
`author` varchar(255) CHARACTER SET utf8 NOT NULL,
`text` text NOT NULL,
`view_order` int(11),
`active` tinyint(1),
PRIMARY KEY (`id_review`) 
) ENGINE=InnoDB  DEFAULT CHARSET=utf8 AUTO_INCREMENT=1 ;
