<?php

if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

/**
 * Description of Review_tmodel
 *
 * @author CIEXT skeleton
 */
class Review_tmodel extends \Ciext\Model\AbstractTableModel
{

    protected $table = 'review';
    protected $pkey = 'id_review';

    public function fetch_all()
    {
        $this->db->where('active', true)->order_by('view_order');
        return parent::fetch_all();
    }
}
